@@ -7,3 +7,11 @@ drop_nulls <- function(x) {
 # Everything above this function in the stack will be hidden by default in the
 # flamegraph.
 ..stacktraceoff.. <- function(x) x
+
+is_installed <- function(pkg) {
+  found <- TRUE
+  tryCatch(utils::packageVersion(pkg),
+    error = function(e) found <<- FALSE
+  )
+  found
+}
